<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>network::systemservice::NetworkInitialization</name>
    <message>
        <source>Wired Connection</source>
        <translation>Connexion filaire</translation>
    </message>
</context>
</TS>